
-- Detroit is at 2410, 1430

require "tiles"

printf = function(s, ...)
	return io.write(s:format(...), "\n")
 end -- function

function love.load()
	game = {}
	game.nom_w = 640
	game.nom_h = 360
	game.real_w = 1280
	game.real_h = 720
	game.nom_real_ratio = game.real_w / game.nom_w
	game.world_w = 4096
	game.world_h = 2304
	game.zoom = 0.25
	game.world_xoff = 2048
	game.world_yoff = 1152
	game.button_d = 0.0
	game.zoom_wait = 0.25
	game.scr_iner = 16
	local r = love.window.setMode( game.real_w, game.real_h, { highdpi=true } )
	if r == false then
		love.errorhandler( "setMode() failed" )
	end
	love.graphics.setDefaultFilter("nearest", "nearest", 0)
	game.mapdata = love.image.newImageData("rust-belt.png")
	game.zonedata = love.image.newImageData("rustbel-rci.png")
	game.map = love.graphics.newImage(game.zonedata)
	-- road: 1872, 1553
	-- R: 1855, 1555
	-- C: 1882, 1575
	-- I: 1868, 1620
	-- Cv: 1901, 1577
	print_colour( game.zonedata, "Road", 1872, 1553 )
	print_colour( game.zonedata, "R", 1855, 1555 )
	print_colour( game.zonedata, "C", 1882, 1575 )
	print_colour( game.zonedata, "I", 1868, 1620 )
	print_colour( game.zonedata, "Cv", 1901, 1577 )
	game.basemap = load_basemap(game.mapdata)
end

function love.draw()
	love.graphics.push()
	-- scale horizontally
	love.graphics.scale(love.graphics.getWidth() / game.nom_w,
		love.graphics.getHeight() / game.nom_h )

	love.graphics.setColor( 0.8, 0.8, 0.8 )
	love.graphics.rectangle( "fill", 0, 0, game.nom_w, game.nom_h )

	love.graphics.draw( game.map, love.graphics.newQuad(
		(game.world_xoff * game.zoom) - (game.nom_w / 2),
		(game.world_yoff * game.zoom) - (game.nom_h / 2),
		game.nom_w, game.nom_h,
		game.world_w * game.zoom,
		game.world_h * game.zoom
	), 0, 0 )
	love.graphics.pop()
end

function love.update(d)
	game.button_d = game.button_d + d
	if game.zoom_wait >= d then
		game.zoom_wait = game.zoom_wait - d
	else
		game.zoom_wait = 0
	end
	if game.button_d >= 0.05 then
		if love.mouse.isDown(1) then
			x = love.mouse.getX( ) / game.nom_real_ratio
			y = love.mouse.getY( ) / game.nom_real_ratio
			-- Report the zoning at this coordinate on map
			r, g, b = strfy_col_xy( x, y )
			-- printf( "Colour: R:%i G:%i B:%i --- ", r, g, b )
			if r == "0.600" and g == "0.255" and b == "0.800" then
				-- road
				printf( "Road @ %i, %i\n", x, y )
			elseif r == "0.541" and g == "0.616" and b == "0.404" then
				-- R
				printf( "Residential zone @ %i, %i\n", x, y )
			elseif r == "0.267" and g == "0.561" and b == "0.804" then
				-- C
				printf( "Commercial zone @ %i, %i\n", x, y )
			elseif r == "0.933" and g == "0.639" and b == "0.133" then
				-- I
				printf( "Industrial zone @ %i, %i\n", x, y )
			elseif r == "0.812" and g == "0.498" and b == "0.204" then
				-- Cv
				printf( "Civic zone @ %i, %i\n", x, y )
			else
				-- printf( "No zoning @ %i, %i\n", x, y )
			end
		end
		local nom_iner = game.scr_iner * (1 / game.zoom)
		if love.keyboard.isDown("left") or love.keyboard.isDown("a") then
			if game.world_xoff < nom_iner then
				game.world_xoff = 0
			else
				game.world_xoff = game.world_xoff - nom_iner
			end
		elseif love.keyboard.isDown("right") or love.keyboard.isDown("d") then
			if game.world_xoff > game.world_w - nom_iner then
				game.world_xoff = game.world_w
			else
				game.world_xoff = game.world_xoff + nom_iner
			end
		elseif love.keyboard.isDown("up") or love.keyboard.isDown("w") then
			if game.world_yoff < nom_iner then
				game.world_yoff = 0
			else
				game.world_yoff = game.world_yoff - nom_iner
			end
		elseif love.keyboard.isDown("down") or love.keyboard.isDown("s") then
			if game.world_yoff > game.world_h - nom_iner then
				game.world_yoff = game.world_h
			else
				game.world_yoff = game.world_yoff + nom_iner
			end
		end
		game.button_d = 0
	elseif game.zoom_wait == 0 then
		if love.keyboard.isDown("=") then
			game.zoom = game.zoom * 2.0
			--game.world_xoff = game.world_xoff * 2.0
			--game.world_yoff = game.world_yoff * 2.0
		elseif love.keyboard.isDown("-") then
			game.zoom = game.zoom / 2.0
			--game.world_xoff = game.world_xoff / 2.0
			--game.world_yoff = game.world_yoff / 2.0
		end
		game.zoom_wait = 0.25
	end
end
